@@ -23,15 +23,17 @@ from .smunger import (
     munge_se,
     munge_z,
 )
+from .liftover import liftover, liftover_file
+from .annotate import annotate_rsid
 
 __author__ = """Jianhua Wang"""
 __email__ = 'jianhua.mert@gmail.com'
-__version__ = '0.0.6'
+__version__ = '0.0.8'
 
 # Set up logging
 logging.basicConfig(
-    level="INFO",
-    format="%(message)s",
+    level=logging.NOTSET,
+    format="%(name)s - %(message)s",
     datefmt="[%X]",
-    handlers=[RichHandler(rich_tracebacks=True)],
+    handlers=[RichHandler(rich_tracebacks=True, show_path=False)],
 )
